.. currentmodule:: h5netcdf.legacyapi

.. _legacyapi:

####################
Legacy API reference
####################

This page provides an auto-generated summary of h5netcdf's legacy API.

.. autosummary::
   :toctree: generated/

   Dataset
   Dataset.createGroup
   Dataset.createDimension
   Dataset.createVariable
   Group
   Dimension
   Variable
   CompoundType
   EnumType
   VLType
